@@ -129,7 +129,7 @@ public:
         void down_thread_run();
         //! realserver remove
         //! @param[in] target endpoint
-        void realserver_remove(boost::asio::ip::tcp::endpoint &);
+        void realserver_remove(const boost::asio::ip::tcp::endpoint &);
 protected:
         typedef data_buff_base<boost::asio::ip::tcp>            tcp_data;
         typedef boost::asio::ip::tcp::endpoint endpoint;
@@ -144,7 +144,6 @@ protected:
                 UP_FUNC_CLIENT_DISCONNECT,                  //! up_thread_client_disconnect function
                 UP_FUNC_CLIENT_DISCONNECT_EVENT,            //! up_thread_client_disconnect_event function
                 UP_FUNC_CLIENT_RECEIVE,                     //! up_thread_client_receive function
-                UP_FUNC_CLIENT_ARECEIVE_HANDLE_EVENT,           //! up_thread_client_asnc_read_some_handler function
                 UP_FUNC_CLIENT_HANDLE_ARECIEVE,                         //! up_thread_client_handle_async_read_some function
                 UP_FUNC_CLIENT_RESPOND_SEND,                //! up_thread_client_respond function
                 UP_FUNC_CLIENT_RESPOND_SEND_EVENT,          //! up_thread_client_respond_event function
@@ -153,8 +152,7 @@ protected:
                 UP_FUNC_REALSERVER_CONNECT_EVENT,           //! up_thread_realserver_connect_event function
                 UP_FUNC_REALSERVER_CONNECT_FAIL_EVENT,      //! up_thread_realserver_connection_fail_event function
                 UP_FUNC_REALSERVER_SEND,                    //! up_thread_realserver_send function
-                UP_FUNC_REALSERVER_ASEND_HANDLE_EVENT,          //! up_thread_realserver_async_write_some_handler function
-                UP_FUNC_REALSERVER_HANDLE_ASEND,                        //! up_thread_realserver_handle_async_write_some function
+                UP_FUNC_REALSERVER_HANDLE_ASYNC_SEND,                        //! up_thread_realserver_handle_async_write_some function
                 UP_FUNC_REALSERVER_DISCONNECT,              //! up_thread_realserver_disconnect function
                 UP_FUNC_REALSERVER_DISCONNECT_EVENT,        //! up_thread_realserver_disconnect_event function
                 UP_FUNC_REALSERVER_ALL_DISCONNECT,                      //! up_thread_realserver_asll_disconnect function
@@ -164,8 +162,7 @@ protected:
                 UP_FUNC_SORRYSERVER_CONNECT_EVENT,          //! up_thread_sorryserver_connect_event function
                 UP_FUNC_SORRYSERVER_CONNECT_FAIL_EVENT,     //! up_thread_sorryserver_connection_fail_event function
                 UP_FUNC_SORRYSERVER_SEND,                   //! up_thread_sorryserver_send function
-                UP_FUNC_SORRYSERVER_ASEND_HANDLE_EVENT,         //! up_thread_sorryserver_async_read_some_handler function
-                UP_FUNC_SORRYSERVER_HANDLE_ASEND,                       //! up_thread_sorryserver_handle_async_read_some function
+                UP_FUNC_SORRYSERVER_HANDLE_ASYNC_SEND,                       //! up_thread_sorryserver_handle_async_read_some function
                 UP_FUNC_SORRYSERVER_DISCONNECT,             //! up_thread_sorryserver_disconnect function
                 UP_FUNC_SORRYSERVER_MOD_DISCONNECT,         //! up_thread_sorryserver_mod_disconnect function
                 UP_FUNC_SORRYSERVER_DISCONNECT_EVENT,       //! up_thread_sorryserver_disconnect_event function
@@ -184,18 +181,15 @@ protected:
                 DOWN_FUNC_CLIENT_DISCONNECT_EVENT,          //! down_thread_client_disconnect_event function
                 DOWN_FUNC_CLIENT_CONNECTION_CHK,            //! down_thread_client_connection_chk_event function
                 DOWN_FUNC_CLIENT_SEND,                      //! down_thread_client_send function
-                DOWN_FUNC_CLIENT_ASEND_HANDLE_EVENT,            //! down_thread_client_async_write_some_handler function
-                DOWN_FUNC_CLIENT_HANDLE_ASEND,                          //! down_thread_client_handle_async_write_some function
+                DOWN_FUNC_CLIENT_HANDLE_ASYNC_SEND,                          //! down_thread_client_handle_async_write_some function
                 DOWN_FUNC_CLIENT_RESPOND_SEND_EVENT,        //! down_thread_client_respond_event function
                 DOWN_FUNC_REALSERVER_RECEIVE,               //! down_thread_realserver_receive function
-                DOWN_FUNC_REALSERVER_ARECEIVE_HANDLE_EVENT,     //! down_thread_realserver_async_read_some_handler function
-                DOWN_FUNC_REALSERVER_HANDLE_ARECEIVE,           //! down_thread_realserver_handle_async_read_some function
+                DOWN_FUNC_REALSERVER_HANDLE_ASYNC_RECEIVE,           //! down_thread_realserver_handle_async_read_some function
                 DOWN_FUNC_REALSERVER_DISCONNECT,            //! down_thread_realserver_disconnect function
                 DOWN_FUNC_REALSERVER_DISCONNECT_EVENT,      //! down_thread_realserver_disconnect_event function
                 DOWN_FUNC_REALSERVER_ALL_DISCONNECT,        //! down_thread_all_realserver_disconnect function
                 DOWN_FUNC_SORRYSERVER_RECEIVE,              //! down_thread_sorryserver_receive function
-                DOWN_FUNC_SORRYSERVER_ARECEIVE_HANDLE_EVENT,    //! down_thread_sorryserver_async_read_some_handler function
-                DOWN_FUNC_SORRYSERVER_HANDLE_ARECEIVE,          //! down_thread_sorryserver_handle_async_read_some function
+                DOWN_FUNC_SORRYSERVER_HANDLE_ASYNC_RECEIVE,          //! down_thread_sorryserver_handle_async_read_some function
                 DOWN_FUNC_SORRYSERVER_DISCONNECT,           //! down_thread_sorryserver_disconnect function
                 DOWN_FUNC_SORRYSERVER_MOD_DISCONNECT,       //! down_thread_sorryserver_mod_disconnect function
                 DOWN_FUNC_SORRYSERVER_DISCONNECT_EVENT,     //! down_thread_sorryserver_disconnect_event function
@@ -542,6 +536,7 @@ protected:
         virtual void down_thread_client_handle_async_write_some(const TCP_PROCESS_TYPE_TAG);
         virtual void down_thread_sorryserver_async_read_some_handler(const boost::system::error_code &error_code, std::size_t len);
         virtual void down_thread_sorryserver_handle_async_read_some(const TCP_PROCESS_TYPE_TAG);
+	virtual void up_thread_client_ssl_socket_clear_socket_handler();
 
         //! down thread receive from realserver and raise module event of handle_realserver_recv
         //! @param[in]        process_type is process type
@@ -633,7 +628,6 @@ protected:
                         : in == UP_FUNC_CLIENT_DISCONNECT              ? "UP_FUNC_CLIENT_DISCONNECT"
                         : in == UP_FUNC_CLIENT_DISCONNECT_EVENT        ? "UP_FUNC_CLIENT_DISCONNECT_EVENT"
                         : in == UP_FUNC_CLIENT_RECEIVE                 ? "UP_FUNC_CLIENT_RECEIVE"
-                        : in == UP_FUNC_CLIENT_ARECEIVE_HANDLE_EVENT   ? "UP_FUNC_CLIENT_ARECIEVE_HANDLE_EVENT"
                         : in == UP_FUNC_CLIENT_HANDLE_ARECIEVE                 ? "UP_FUNC_CLIENT_HANDLE_ARECIEVE"
                         : in == UP_FUNC_CLIENT_RESPOND_SEND            ? "UP_FUNC_CLIENT_RESPOND_SEND"
                         : in == UP_FUNC_CLIENT_RESPOND_SEND_EVENT      ? "UP_FUNC_CLIENT_RESPOND_SEND_EVENT"
@@ -642,8 +636,7 @@ protected:
                         : in == UP_FUNC_REALSERVER_CONNECT_EVENT       ? "UP_FUNC_REALSERVER_CONNECT_EVENT"
                         : in == UP_FUNC_REALSERVER_CONNECT_FAIL_EVENT  ? "UP_FUNC_REALSERVER_CONNECT_FAIL_EVENT"
                         : in == UP_FUNC_REALSERVER_SEND                ? "UP_FUNC_REALSERVER_SEND"
-                        : in == UP_FUNC_REALSERVER_ASEND_HANDLE_EVENT  ? "UP_FUNC_REALSERVER_ASEND_HANDLE_EVENT"
-                        : in == UP_FUNC_REALSERVER_HANDLE_ASEND        ? "UP_FUNC_REALSERVER_HANDLE_ASEND"
+                        : in == UP_FUNC_REALSERVER_HANDLE_ASYNC_SEND        ? "UP_FUNC_REALSERVER_HANDLE_ASYNC_SEND"
                         : in == UP_FUNC_REALSERVER_DISCONNECT          ? "UP_FUNC_REALSERVER_DISCONNECT"
                         : in == UP_FUNC_REALSERVER_DISCONNECT_EVENT    ? "UP_FUNC_REALSERVER_DISCONNECT_EVENT"
                         : in == UP_FUNC_REALSERVER_ALL_DISCONNECT              ? "UP_FUNC_REALSERVER_ALL_DISCONNECT"
@@ -653,8 +646,7 @@ protected:
                         : in == UP_FUNC_SORRYSERVER_CONNECT_EVENT      ? "UP_FUNC_SORRYSERVER_CONNECT_EVENT"
                         : in == UP_FUNC_SORRYSERVER_CONNECT_FAIL_EVENT ? "UP_FUNC_SORRYSERVER_CONNECT_FAIL_EVENT"
                         : in == UP_FUNC_SORRYSERVER_SEND               ? "UP_FUNC_SORRYSERVER_SEND"
-                        : in == UP_FUNC_SORRYSERVER_ASEND_HANDLE_EVENT ? "UP_FUNC_SORRYSERVER_ASEND_HANDLE_EVENT"
-                        : in == UP_FUNC_SORRYSERVER_HANDLE_ASEND       ? "UP_FUNC_SORRYSERVER_HANDLE_ASEND"
+                        : in == UP_FUNC_SORRYSERVER_HANDLE_ASYNC_SEND       ? "UP_FUNC_SORRYSERVER_HANDLE_ASYNC_SEND"
                         : in == UP_FUNC_SORRYSERVER_DISCONNECT         ? "UP_FUNC_SORRYSERVER_DISCONNECT"
                         : in == UP_FUNC_SORRYSERVER_MOD_DISCONNECT     ? "UP_FUNC_SORRYSERVER_MOD_DISCONNECT"
                         : in == UP_FUNC_SORRYSERVER_DISCONNECT_EVENT   ? "UP_FUNC_SORRYSERVER_DISCONNECT_EVENT"
@@ -672,17 +664,14 @@ protected:
                         : in == DOWN_FUNC_CLIENT_DISCONNECT_EVENT      ? "DOWN_FUNC_CLIENT_DISCONNECT_EVENT"
                         : in == DOWN_FUNC_CLIENT_CONNECTION_CHK        ? "DOWN_FUNC_CLIENT_CONNECTION_CHK"
                         : in == DOWN_FUNC_CLIENT_SEND                  ? "DOWN_FUNC_CLIENT_SEND"
-                        : in == DOWN_FUNC_CLIENT_ASEND_HANDLE_EVENT    ? "DOWN_FUNC_CLIENT_ASEND_HANDLE_EVENT"
-                        : in == DOWN_FUNC_CLIENT_HANDLE_ASEND          ? "DOWN_FUNC_CLIENT_HANDLE_ASEND"
+                        : in == DOWN_FUNC_CLIENT_HANDLE_ASYNC_SEND          ? "DOWN_FUNC_CLIENT_HANDLE_ASYNC_SEND"
                         : in == DOWN_FUNC_CLIENT_RESPOND_SEND_EVENT    ? "DOWN_FUNC_CLIENT_RESPOND_SEND_EVENT"
                         : in == DOWN_FUNC_REALSERVER_RECEIVE           ? "DOWN_FUNC_REALSERVER_RECEIVE"
-                        : in == DOWN_FUNC_REALSERVER_ARECEIVE_HANDLE_EVENT ? "DOWN_FUNC_REALSERVER_ARECEIVE_HANDLE_EVENT"
-                        : in == DOWN_FUNC_REALSERVER_HANDLE_ARECEIVE   ? "DOWN_FUNC_REALSERVER_HANDLE_ARECEIVE"
+                        : in == DOWN_FUNC_REALSERVER_HANDLE_ASYNC_RECEIVE   ? "DOWN_FUNC_REALSERVER_HANDLE_ASYNC_RECEIVE"
                         : in == DOWN_FUNC_REALSERVER_DISCONNECT        ? "DOWN_FUNC_REALSERVER_DISCONNECT"
                         : in == DOWN_FUNC_REALSERVER_DISCONNECT_EVENT  ? "DOWN_FUNC_REALSERVER_DISCONNECT_EVENT"
                         : in == DOWN_FUNC_SORRYSERVER_RECEIVE          ? "DOWN_FUNC_SORRYSERVER_RECEIVE"
-                        : in == DOWN_FUNC_SORRYSERVER_ARECEIVE_HANDLE_EVENT ? "DOWN_FUNC_SORRYSERVER_ARECEIVE_HANDLE_EVENT"
-                        : in == DOWN_FUNC_SORRYSERVER_HANDLE_ARECEIVE  ? "DOWN_FUNC_SORRYSERVER_HANDLE_ARECEIVE"
+                        : in == DOWN_FUNC_SORRYSERVER_HANDLE_ASYNC_RECEIVE  ? "DOWN_FUNC_SORRYSERVER_HANDLE_ASYNC_RECEIVE"
                         : in == DOWN_FUNC_SORRYSERVER_DISCONNECT       ? "DOWN_FUNC_SORRYSERVER_DISCONNECT"
                         : in == DOWN_FUNC_SORRYSERVER_MOD_DISCONNECT   ? "DOWN_FUNC_SORRYSERVER_MOD_DISCONNECT"
                         : in == DOWN_FUNC_SORRYSERVER_DISCONNECT_EVENT ? "DOWN_FUNC_SORRYSERVER_DISCONNECT_EVENT"
